@@ -84,7 +84,7 @@ class AccessKey(PersistentJSONable):
 
 
     @classmethod
-    def construct_from_jdict(cls, jdict, default=True):
+    def construct_from_jdict(cls, jdict, skeleton=False):
         if not jdict:
             return None
 
@@ -100,6 +100,8 @@ class AccessKey(PersistentJSONable):
         """
         Constructor
         """
+        super().__init__()
+
         self.__id = id                              # string
         self.__secret = secret                      # string
 
