@@ -24,7 +24,7 @@ class EmailList(PersistentJSONable):
     # ----------------------------------------------------------------------------------------------------------------
 
     @classmethod
-    def construct_from_jdict(cls, jdict, default=True):
+    def construct_from_jdict(cls, jdict, skeleton=False):
         if not jdict:
             return None
 
@@ -47,6 +47,8 @@ class EmailList(PersistentJSONable):
         """
         Constructor
         """
+        super().__init__()
+
         self.__email_list = email_list
 
 
