@@ -28,7 +28,7 @@ class RuntimeRecord(PersistentJSONable):
 
 
     @classmethod
-    def construct_from_jdict(cls, jdict, default=True):
+    def construct_from_jdict(cls, jdict, skeleton=False):
         if not jdict:
             return None
 
@@ -43,8 +43,11 @@ class RuntimeRecord(PersistentJSONable):
         """
         Constructor
         """
+        super().__init__()
+
         self.__last_runtime = last_runtime
 
+
     # ----------------------------------------------------------------------------------------------------------------
 
     @property
