@@ -24,6 +24,7 @@ from scs_core.data.datetime import LocalizedDatetime
 from scs_core.data.json import PersistentJSONable
 from scs_core.data.path_dict import PathDict
 
+from scs_core.sys.filesystem import Filesystem
 from scs_core.sys.logging import Logging
 from scs_core.sys.system_id import SystemID
 
@@ -43,7 +44,7 @@ class AWSGroupConfiguration(PersistentJSONable):
 
     @classmethod
     def templates(cls):
-        return [item for item in sorted(os.listdir(cls.catalogue_location()))]
+        return [item.name for item in Filesystem.ls(cls.catalogue_location()) if item.is_directory]
 
 
     @classmethod
@@ -229,6 +230,7 @@ class AWSGroupConfigurator(object):
         group_owner_name = temp.split("/")[2]
         scs_path = host.scs_path()
         r_data["Name"] = ("Resources-" + system_id)  # Edit resources name
+
         r_data["InitialVersion"]["Resources"][0]["Id"] = (
                 system_id + "-data-volume")  # Edit resource name
         r_data["InitialVersion"]["Resources"][0]["ResourceDataContainer"]["LocalVolumeResourceData"][
@@ -248,6 +250,18 @@ class AWSGroupConfigurator(object):
             r_data["InitialVersion"]["Resources"][4]["Id"] = (
                 (system_id + "-ml-no2"))  # Edit resource name
 
+            try:
+                r_data["InitialVersion"]["Resources"][5]["Id"] = (
+                    (system_id + "-ml-no"))  # Edit resource name
+            except IndexError:
+                pass
+
+            try:
+                r_data["InitialVersion"]["Resources"][6]["Id"] = (
+                    (system_id + "-ml-so2"))  # Edit resource name
+            except IndexError:
+                pass
+
         # Send request
         self.__logger.info("Creating resource definition")
         self.__logger.info(r_data)
@@ -274,6 +288,7 @@ class AWSGroupConfigurator(object):
             "ResourceId"] = data_volume_name
         f_data["InitialVersion"]["Functions"][1]["FunctionConfiguration"]["Environment"]["ResourceAccessPolicies"][0][
             "ResourceId"] = data_volume_name
+
         if self.config.ml:
             f_data["InitialVersion"]["Functions"][2]["Id"] = (system_id + "-PMxInference")
             f_data["InitialVersion"]["Functions"][2]["FunctionConfiguration"]["Environment"]["ResourceAccessPolicies"][
@@ -291,6 +306,18 @@ class AWSGroupConfigurator(object):
             f_data["InitialVersion"]["Functions"][3]["FunctionConfiguration"]["Environment"]["ResourceAccessPolicies"][
                 1]["ResourceId"] = (system_id + "-ml-no2")
 
+            try:
+                f_data["InitialVersion"]["Functions"][3]["FunctionConfiguration"]["Environment"][
+                    "ResourceAccessPolicies"][2]["ResourceId"] = (system_id + "-ml-no")
+            except IndexError:
+                pass
+
+            try:
+                f_data["InitialVersion"]["Functions"][3]["FunctionConfiguration"]["Environment"][
+                    "ResourceAccessPolicies"][3]["ResourceId"] = (system_id + "-ml-so2")
+            except IndexError:
+                pass
+
         self.__logger.info("Creating function definition")
         self.__logger.info(f_data)
 
