@@ -38,7 +38,7 @@ class AWSIdentity(PersistentJSONable):
 
 
     @classmethod
-    def construct_from_jdict(cls, jdict, default=True):
+    def construct_from_jdict(cls, jdict, skeleton=False):
         if jdict is None:
             return None
 
@@ -86,6 +86,8 @@ class AWSIdentity(PersistentJSONable):
         """
         Constructor
         """
+        super().__init__()
+
         self.__logger = Logging.getLogger()
 
         self.__iot_client = iot_client
