@@ -39,7 +39,11 @@ class ParticulatesSample(Sample):
 
         # Sample...
         tag = jdict.get('tag')
-        version = jdict.get('ver', cls.DEFAULT_VERSION)
+
+        try:
+            version = float(jdict.get('ver'))
+        except (TypeError, ValueError):
+            version = cls.DEFAULT_VERSION
 
         val = jdict.get('val')
         exegeses = jdict.get('exg')
