@@ -32,7 +32,11 @@ class Sample(JSONable):
 
         tag = jdict.get('tag')
         rec = LocalizedDatetime.construct_from_jdict(jdict.get('rec'))
-        version = jdict.get('ver', cls.DEFAULT_VERSION)
+
+        try:
+            version = float(jdict.get('ver'))
+        except (TypeError, ValueError):
+            version = cls.DEFAULT_VERSION
 
         src = jdict.get('src')
         values = jdict.get('val')
