@@ -27,10 +27,6 @@ class TimedRunner(Runner):
 
     # ----------------------------------------------------------------------------------------------------------------
 
-    def reset(self):
-        self.__timer = IntervalTimer(self.__timer.interval)
-
-
     def samples(self, sampler):
         self.reset()                                # reset to prevent uneven intervals
 
@@ -43,6 +39,10 @@ class TimedRunner(Runner):
                 yield sampler.sample()
 
 
+    def reset(self):
+        self.__timer.reset()
+
+
     # ----------------------------------------------------------------------------------------------------------------
 
     @property
